@@ -50,11 +50,11 @@ test_that("GMM hybrid", {
   expect_equal(ncol(do.call(rbind, co$muk)), 2)
   expect_equal(sum(co$pi), 1)
   expect_equal(length(co$pi), 3)
-  expect_true(is.ggplot(plot(solc, type = "tree")))
-  expect_true(is.ggplot(plot(solc, type = "path")))
-  expect_true(is.ggplot(plot(solc, type = "front")))
-  expect_true(methods::is(plot(solc, type = "violins"), "gtable"))
-  expect_true(methods::is(plot(solc, type = "marginals"), "gtable"))
+  # expect_true(is.ggplot(plot(solc, type = "tree")))
+  # expect_true(is.ggplot(plot(solc, type = "path")))
+  # expect_true(is.ggplot(plot(solc, type = "front")))
+  #expect_true(methods::is(plot(solc, type = "violins"), "gtable"))
+  #expect_true(methods::is(plot(solc, type = "marginals"), "gtable"))
 })
 
 test_that("GMM seed", {
@@ -63,9 +63,9 @@ test_that("GMM seed", {
   sol <- greed(X, alg = Seed())
   expect_equal(sol@K, 3)
   solc <- cut(sol, 2)
-  expect_true(is.ggplot(plot(solc, type = "tree")))
-  expect_true(is.ggplot(plot(solc, type = "path")))
-  expect_true(is.ggplot(plot(solc, type = "front")))
-  expect_true(methods::is(plot(solc, type = "violins"), "gtable"))
-  expect_true(methods::is(plot(solc, type = "marginals"), "gtable"))
+  # expect_true(is.ggplot(plot(solc, type = "tree")))
+  # expect_true(is.ggplot(plot(solc, type = "path")))
+  # expect_true(is.ggplot(plot(solc, type = "front")))
+  #expect_true(methods::is(plot(solc, type = "violins"), "gtable"))
+  #expect_true(methods::is(plot(solc, type = "marginals"), "gtable"))
 })
